/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-11-20 14:16:22.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.service.bean.coursepaper;

import cn.com.qmth.examcloud.api.commons.exchange.JsonSerializable;
import cn.com.qmth.examcloud.core.print.enums.ExportType;

/**
 * 整体导出(请求)
 *
 * @author: QMTH
 * @since: 2018/11/01
 */
public class ExportAllReq implements JsonSerializable {
    private static final long serialVersionUID = 1L;
    /**
     * 学校机构ID
     */
    private Long orgId;
    /**
     * 考试ID
     */
    private Long examId;
    /**
     * 是否需要导出试卷
     */
    private Boolean needPaper;
    /**
     * 是否需要导出答案
     */
    private Boolean needAnswer;
    /**
     * 是否需要导出试卷结构
     */
    private Boolean needStruct;

    public ExportAllReq(Long orgId, Long examId, Integer[] types) {
        this.orgId = orgId;
        this.examId = examId;
        for (Integer type : types) {
            if (ExportType.PAPER.getId() == type) {
                this.needPaper = true;
            } else if (ExportType.ANSWER.getId() == type) {
                this.needAnswer = true;
            } else if (ExportType.STRUCT.getId() == type) {
                this.needStruct = true;
            }
        }
    }

    public boolean required() {
        //至少选择一种
        if (getNeedPaper()) {
            return true;
        }
        if (getNeedAnswer()) {
            return true;
        }
        if (getNeedStruct()) {
            return true;
        }
        return false;
    }

    public ExportAllReq() {

    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public Long getExamId() {
        return examId;
    }

    public void setExamId(Long examId) {
        this.examId = examId;
    }

    public Boolean getNeedPaper() {
        return needPaper != null ? needPaper : false;
    }

    public void setNeedPaper(Boolean needPaper) {
        this.needPaper = needPaper;
    }

    public Boolean getNeedAnswer() {
        return needAnswer != null ? needAnswer : false;
    }

    public void setNeedAnswer(Boolean needAnswer) {
        this.needAnswer = needAnswer;
    }

    public Boolean getNeedStruct() {
        return needStruct != null ? needStruct : false;
    }

    public void setNeedStruct(Boolean needStruct) {
        this.needStruct = needStruct;
    }

}